/*  XMPS - X MPEG Player System
 *  Copyright (C) 1999 Damien Chavarria
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public Licensse as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/**
 *
 * plugin.h
 *
 * Plugins specifications.
 * @Author Chavarria Damien.
 * 	   Copyright 1999-2000
 */

#ifndef _XMPS_PLUGIN_H
#define _XMPS_PLUGIN_H

#include <glib.h>

#include <xmps_config.h>
#include "xmps_message.h"
#include "types.h"

enum { SDL, X11, OpenGL };

typedef struct {
  
  void *handle;
  char *filename;         
  char *description;      
  int   enabled;

  // Setup functions
 
  void            (*init) (void);    
  void            (*set_surface) (void *surface);
  void            (*set_callback) (XMPS_DisplayCallback callback);  
  void            (*scale) (int x, int y);
  int             (*move_into_display) (int x, int y);
  GList*          (*get_available_formats)(void);
  int             (*set_format)(XMPSVideoFormat format);
  int             (*set_lock_func)(XMPS_VideoLockFunc f);
  int             (*set_mode)(XMPSVideoMode);

  // Info/Set functions

  int             (*is_our_file) (char *filename);
  XMPSCodecStatus (*get_status) (void);
  int             (*has_file)   (void);
  void            (*video_info) (XMPSVideoInfo *info);
  unsigned int    (*get_actual_position) (void);
  unsigned int    (*get_file_size) (char *filename);
  void            (*get_volume) (void);    
  void            (*set_volume) (int volume);        
 
  // Playback functions

  int  (*open) (char *filename);
  void (*play) ();     
  void (*stop) (void);    
  void (*pause) (void);  
  void (*rewind) (void);   
  void (*seek) (int percent);        
  void (*close) (void);

  // Misc GTK/Configuration functions

  void (*about) (void);
  void (*configure) (void);
  void (*load_options) (ConfigFile *cfg);
  void (*save_options) (ConfigFile *cfg);
  void (*file_info_box) (char *filename);   

} XMPSCodec;


typedef struct  {
 
  void *handle;
  char *filename;      
  char *description;
  char *text;

  XMPSCodec *current_codec;

  // Setup functions

  int                  (*init)(void);
  GList*               (*get_available_formats)(void);
  XMPSVideoMode        (*get_mode)(void);
  XMPS_DisplayCallback (*get_callback)(void);
  int                  (*set_format)(XMPSVideoFormat format);
  XMPS_VideoLockFunc   (*get_lock_func)(void);
  int                  (*move_display)(int x, int y);
  int                  (*use_window_id)(int id);

  // Playback functions

  int                  (*create_surface)(XMPSCodec *codec);
  void*                (*get_surface)(void);
  int                  (*destroy_surface)();
  int                  (*go_fullscreen)();
  long                 (*get_drawed_frames)();

  // Events functions

  int                  (*handle_structure_event)(int x, int y);
  int                  (*check_for_events)();
  
} XMPSRenderer;


#endif
